==> qore-0.8.11.tar.bz2: qore-0.8.11/docs/modules/SqlUtil/html/search/variables_64.js <==
var searchData=
[
  ['databaseoptions',['DatabaseOptions',['../class_sql_util_1_1_abstract_database.html#aa386241ce2cec030485543ccf2800b95',1,'SqlUtil::AbstractDatabase']]],
  ['date',['Date',['../../../../lang/html/group__string__type__constants.html#ga6f9e84261496df48b2564e7acf8afb3d',1,'Qore::Type::Date()'],['../../../../lang/html/group__string__type__constants.html#ga6f9e84261496df48b2564e7acf8afb3d',1,'Date()(Global Namespace)'],['../../../../lang/html/group__sql__constants.html#ga56cd886db959d27929f4700ab0d9d43a',1,'Qore::SQL::DATE()'],['../../../../lang/html/group__sql__constants.html#ga56cd886db959d27929f4700ab0d9d43a',1,'DATE()(Global Namespace)']]],
  ['db',['db',['../class_sql_util_1_1_database.html#a0ecf8f2bba204a2a1e60b869c0e2f0df',1,'SqlUtil::Database']]],
  ['db_5ffunctions',['DB_FUNCTIONS',['../namespace_sql_util.html#ae624d72f6c5e974cff42b38bfa0d3ef9',1,'SqlUtil']]],
  ['db_5fmviews',['DB_MVIEWS',['../namespace_sql_util.html#a5a138440c28ea7a20cc301a7a546397f',1,'SqlUtil']]],
  ['db_5fpackages',['DB_PACKAGES',['../namespace_sql_util.html#a1ce94dd1f978cb1b22c75c7e3f6a418e',1,'SqlUtil']]],
  ['db_5fprocedures',['DB_PROCEDURES',['../namespace_sql_util.html#a94f9172d04a891ce648a2b462ba6cacd',1,'SqlUtil']]],
  ['db_5fsequences',['DB_SEQUENCES',['../namespace_sql_util.html#af691e709f12db51da8ed4938b730047d',1,'SqlUtil']]],
  ['db_5ftables',['DB_TABLES',['../namespace_sql_util.html#aaea27e7ce6be034c14f74985aa0d1ae0',1,'SqlUtil']]],
  ['db_5ftypes',['DB_TYPES',['../namespace_sql_util.html#af70f6295063645aa3aa9731e33c212cc',1,'SqlUtil']]],
  ['db_5fviews',['DB_VIEWS',['../namespace_sql_util.html#ac01e40dff665219610a27eaed220fa1b',1,'SqlUtil']]],
  ['dbi_5fcap_5fautoreconnect',['DBI_CAP_AUTORECONNECT',['../../../../lang/html/group__dbi__capabilities.html#gae77508d8a9b7f53e3f0a35f76cf59511',1,'Qore::SQL::DBI_CAP_AUTORECONNECT()'],['../../../../lang/html/group__dbi__capabilities.html#gae77508d8a9b7f53e3f0a35f76cf59511',1,'DBI_CAP_AUTORECONNECT()(Global Namespace)']]],
  ['dbi_5fcap_5fbind_5fby_5fplaceholder',['DBI_CAP_BIND_BY_PLACEHOLDER',['../../../../lang/html/group__dbi__capabilities.html#gac6adedead4bf1317f03b575dc1276351',1,'Qore::SQL::DBI_CAP_BIND_BY_PLACEHOLDER()'],['../../../../lang/html/group__dbi__capabilities.html#gac6adedead4bf1317f03b575dc1276351',1,'DBI_CAP_BIND_BY_PLACEHOLDER()(Global Namespace)']]],
  ['dbi_5fcap_5fbind_5fby_5fvalue',['DBI_CAP_BIND_BY_VALUE',['../../../../lang/html/group__dbi__capabilities.html#ga369027092e18434a428c0ba401986964',1,'Qore::SQL::DBI_CAP_BIND_BY_VALUE()'],['../../../../lang/html/group__dbi__capabilities.html#ga369027092e18434a428c0ba401986964',1,'DBI_CAP_BIND_BY_VALUE()(Global Namespace)']]],
  ['dbi_5fcap_5fcharset_5fsupport',['DBI_CAP_CHARSET_SUPPORT',['../../../../lang/html/group__dbi__capabilities.html#ga382bb241f164431cf2e5c0e161b1bdd2',1,'Qore::SQL::DBI_CAP_CHARSET_SUPPORT()'],['../../../../lang/html/group__dbi__capabilities.html#ga382bb241f164431cf2e5c0e161b1bdd2',1,'DBI_CAP_CHARSET_SUPPORT()(Global Namespace)']]],
  ['dbi_5fcap_5fevents',['DBI_CAP_EVENTS',['../../../../lang/html/group__dbi__capabilities.html#gae187e09b0775647d1b1afd2d3b43570f',1,'Qore::SQL::DBI_CAP_EVENTS()'],['../../../../lang/html/group__dbi__capabilities.html#gae187e09b0775647d1b1afd2d3b43570f',1,'DBI_CAP_EVENTS()(Global Namespace)']]],
  ['dbi_5fcap_5fhas_5fdescribe',['DBI_CAP_HAS_DESCRIBE',['../../../../lang/html/group__dbi__capabilities.html#ga775d0748c664e8ced5a2ef953496aa8c',1,'Qore::SQL::DBI_CAP_HAS_DESCRIBE()'],['../../../../lang/html/group__dbi__capabilities.html#ga775d0748c664e8ced5a2ef953496aa8c',1,'DBI_CAP_HAS_DESCRIBE()(Global Namespace)']]],
  ['dbi_5fcap_5fhas_5fexecraw',['DBI_CAP_HAS_EXECRAW',['../../../../lang/html/group__dbi__capabilities.html#gad3033ee84e18d57a95da98e01bdae383',1,'Qore::SQL::DBI_CAP_HAS_EXECRAW()'],['../../../../lang/html/group__dbi__capabilities.html#gad3033ee84e18d57a95da98e01bdae383',1,'DBI_CAP_HAS_EXECRAW()(Global Namespace)']]],
  ['dbi_5fcap_5fhas_5fnumber_5fsupport',['DBI_CAP_HAS_NUMBER_SUPPORT',['../../../../lang/html/group__dbi__capabilities.html#ga8394d1495944bf61d666de40489a038a',1,'Qore::SQL::DBI_CAP_HAS_NUMBER_SUPPORT()'],['../../../../lang/html/group__dbi__capabilities.html#ga8394d1495944bf61d666de40489a038a',1,'DBI_CAP_HAS_NUMBER_SUPPORT()(Global Namespace)']]],
  ['dbi_5fcap_5fhas_5foption_5fsupport',['DBI_CAP_HAS_OPTION_SUPPORT',['../../../../lang/html/group__dbi__capabilities.html#ga428f8f4909b2737d03593d8808fe2227',1,'Qore::SQL::DBI_CAP_HAS_OPTION_SUPPORT()'],['../../../../lang/html/group__dbi__capabilities.html#ga428f8f4909b2737d03593d8808fe2227',1,'DBI_CAP_HAS_OPTION_SUPPORT()(Global Namespace)']]],
  ['dbi_5fcap_5fhas_5fselect_5frow',['DBI_CAP_HAS_SELECT_ROW',['../../../../lang/html/group__dbi__capabilities.html#ga8a1c46d41ccafebf758dfe3d1116657c',1,'Qore::SQL::DBI_CAP_HAS_SELECT_ROW()'],['../../../../lang/html/group__dbi__capabilities.html#ga8a1c46d41ccafebf758dfe3d1116657c',1,'DBI_CAP_HAS_SELECT_ROW()(Global Namespace)']]],
  ['dbi_5fcap_5fhas_5fstatement',['DBI_CAP_HAS_STATEMENT',['../../../../lang/html/group__dbi__capabilities.html#ga527e40359b876f12a4cb59fec305969d',1,'Qore::SQL::DBI_CAP_HAS_STATEMENT()'],['../../../../lang/html/group__dbi__capabilities.html#ga527e40359b876f12a4cb59fec305969d',1,'DBI_CAP_HAS_STATEMENT()(Global Namespace)']]],
  ['dbi_5fcap_5flob_5fsupport',['DBI_CAP_LOB_SUPPORT',['../../../../lang/html/group__dbi__capabilities.html#ga3a641cb4afbeb873fd9fe97f020f09eb',1,'Qore::SQL::DBI_CAP_LOB_SUPPORT()'],['../../../../lang/html/group__dbi__capabilities.html#ga3a641cb4afbeb873fd9fe97f020f09eb',1,'DBI_CAP_LOB_SUPPORT()(Global Namespace)']]],
  ['dbi_5fcap_5fserver_5ftime_5fzone',['DBI_CAP_SERVER_TIME_ZONE',['../../../../lang/html/group__dbi__capabilities.html#ga9edf0826e734f77115fd8f1001cf4a9e',1,'Qore::SQL::DBI_CAP_SERVER_TIME_ZONE()'],['../../../../lang/html/group__dbi__capabilities.html#ga9edf0826e734f77115fd8f1001cf4a9e',1,'DBI_CAP_SERVER_TIME_ZONE()(Global Namespace)']]],
  ['dbi_5fcap_5fstored_5fprocedures',['DBI_CAP_STORED_PROCEDURES',['../../../../lang/html/group__dbi__capabilities.html#gac5e26138ae8e0957e7dba50d8a96cb6c',1,'Qore::SQL::DBI_CAP_STORED_PROCEDURES()'],['../../../../lang/html/group__dbi__capabilities.html#gac5e26138ae8e0957e7dba50d8a96cb6c',1,'DBI_CAP_STORED_PROCEDURES()(Global Namespace)']]],
  ['dbi_5fcap_5ftime_5fzone_5fsupport',['DBI_CAP_TIME_ZONE_SUPPORT',['../../../../lang/html/group__dbi__capabilities.html#gab97795225e7b52a4a063c1770c4fec7c',1,'Qore::SQL::DBI_CAP_TIME_ZONE_SUPPORT()'],['../../../../lang/html/group__dbi__capabilities.html#gab97795225e7b52a4a063c1770c4fec7c',1,'DBI_CAP_TIME_ZONE_SUPPORT()(Global Namespace)']]],
  ['dbi_5fcap_5ftransaction_5fmanagement',['DBI_CAP_TRANSACTION_MANAGEMENT',['../../../../lang/html/group__dbi__capabilities.html#ga62b0bd7a4e0611fbe8848002aa6711c8',1,'Qore::SQL::DBI_CAP_TRANSACTION_MANAGEMENT()'],['../../../../lang/html/group__dbi__capabilities.html#ga62b0bd7a4e0611fbe8848002aa6711c8',1,'DBI_CAP_TRANSACTION_MANAGEMENT()(Global Namespace)']]],
  ['decimal',['DECIMAL',['../../../../lang/html/group__sql__constants.html#ga85bba3f8e978509f66f08011b264e9b0',1,'Qore::SQL::DECIMAL()'],['../../../../lang/html/group__sql__constants.html#ga85bba3f8e978509f66f08011b264e9b0',1,'DECIMAL()(Global Namespace)']]],
  ['def_5fval',['def_val',['../class_sql_util_1_1_abstract_column.html#a519e6ac1e7288647898baf62720219be',1,'SqlUtil::AbstractColumn']]],
  ['defaultcopmap',['DefaultCopMap',['../group__sql__cops.html#gae497d7c4b1316f78ea93522f8b7cd554',1,'SqlUtil']]],
  ['defaultiopmap',['DefaultIopMap',['../group__sql__iops.html#ga82d74e87e1f9365eeb902dce0a481132',1,'SqlUtil']]],
  ['defaultiv',['DefaultIV',['../../../../lang/html/group__cryptographic__constants.html#ga3e258a2c4d9e99eb43a97e7bf1dbe870',1,'Qore::DefaultIV()'],['../../../../lang/html/group__cryptographic__constants.html#ga3e258a2c4d9e99eb43a97e7bf1dbe870',1,'DefaultIV()(Global Namespace)']]],
  ['defaultopmap',['DefaultOpMap',['../group__sql__ops.html#ga48d22f47fdbfb3cc9053235a709f2a17',1,'SqlUtil']]],
  ['defaultuopmap',['DefaultUopMap',['../namespace_sql_util.html#a1f1c6a2c131d48856844f8de25976bc5',1,'SqlUtil']]],
  ['dropschemaoptions',['DropSchemaOptions',['../class_sql_util_1_1_abstract_database.html#a1316a5c73ddff6d6f38cf6460c6df798',1,'SqlUtil::AbstractDatabase']]],
  ['ds',['ds',['../class_sql_util_1_1_abstract_sql_util_base.html#a9702e036a29d0001b493ba8fe087f612',1,'SqlUtil::AbstractSqlUtilBase']]],
  ['dsdb2',['DSDB2',['../../../../lang/html/group__database__driver__constants.html#ga0baaf1dccf027f143466257478c8b647',1,'Qore::SQL::DSDB2()'],['../../../../lang/html/group__database__driver__constants.html#ga0baaf1dccf027f143466257478c8b647',1,'DSDB2()(Global Namespace)']]],
  ['dsdesc',['dsdesc',['../class_sql_util_1_1_abstract_sql_util_base.html#a99e661a4e2125368244a09c93c8aab8d',1,'SqlUtil::AbstractSqlUtilBase']]],
  ['dsfreetds',['DSFreeTDS',['../../../../lang/html/group__database__driver__constants.html#ga3e14e0949befa85b7c2993dd7a369811',1,'Qore::SQL::DSFreeTDS()'],['../../../../lang/html/group__database__driver__constants.html#ga3e14e0949befa85b7c2993dd7a369811',1,'DSFreeTDS()(Global Namespace)']]],
  ['dsmssql',['DSMSSQL',['../../../../lang/html/group__database__driver__constants.html#ga6cec46106d85f35a513ebb3d7b751cef',1,'Qore::SQL::DSMSSQL()'],['../../../../lang/html/group__database__driver__constants.html#ga6cec46106d85f35a513ebb3d7b751cef',1,'DSMSSQL()(Global Namespace)']]],
  ['dsmysql',['DSMySQL',['../../../../lang/html/group__database__driver__constants.html#ga09de83cb35f39d717e612dffc0d55cf6',1,'Qore::SQL::DSMySQL()'],['../../../../lang/html/group__database__driver__constants.html#ga09de83cb35f39d717e612dffc0d55cf6',1,'DSMySQL()(Global Namespace)']]],
  ['dsoracle',['DSOracle',['../../../../lang/html/group__database__driver__constants.html#gada3f880c40b777b843b944d585404e70',1,'Qore::SQL::DSOracle()'],['../../../../lang/html/group__database__driver__constants.html#gada3f880c40b777b843b944d585404e70',1,'DSOracle()(Global Namespace)']]],
  ['dspgsql',['DSPGSQL',['../../../../lang/html/group__database__driver__constants.html#gac3ce6e6daf3c2bedbc927905e744b45b',1,'Qore::SQL::DSPGSQL()'],['../../../../lang/html/group__database__driver__constants.html#gac3ce6e6daf3c2bedbc927905e744b45b',1,'DSPGSQL()(Global Namespace)']]],
  ['dssqlite3',['DSSQLite3',['../../../../lang/html/group__database__driver__constants.html#ga116c8e3a222a4f13965519d9241665c3',1,'Qore::SQL::DSSQLite3()'],['../../../../lang/html/group__database__driver__constants.html#ga116c8e3a222a4f13965519d9241665c3',1,'DSSQLite3()(Global Namespace)']]],
  ['dssybase',['DSSybase',['../../../../lang/html/group__database__driver__constants.html#ga39a5356b7cee1ef4b8a47e02dfe65f05',1,'Qore::SQL::DSSybase()'],['../../../../lang/html/group__database__driver__constants.html#ga39a5356b7cee1ef4b8a47e02dfe65f05',1,'DSSybase()(Global Namespace)']]]
];

==> qore-0.8.12.2.tar.bz2: qore-0.8.12.2/docs/modules/SqlUtil/html/search/variables_64.js <==
var searchData=
[
  ['databaseoptions',['DatabaseOptions',['../class_sql_util_1_1_abstract_database.html#aa386241ce2cec030485543ccf2800b95',1,'SqlUtil::AbstractDatabase']]],
  ['date',['Date',['../../../../lang/html/group__string__type__constants.html#ga6f9e84261496df48b2564e7acf8afb3d',1,'Qore::Type::Date()'],['../../../../lang/html/group__string__type__constants.html#ga6f9e84261496df48b2564e7acf8afb3d',1,'Date()(Global Namespace)'],['../../../../lang/html/group__sql__constants.html#ga56cd886db959d27929f4700ab0d9d43a',1,'Qore::SQL::DATE()'],['../../../../lang/html/group__sql__constants.html#ga56cd886db959d27929f4700ab0d9d43a',1,'DATE()(Global Namespace)']]],
  ['db',['db',['../class_sql_util_1_1_database.html#a0ecf8f2bba204a2a1e60b869c0e2f0df',1,'SqlUtil::Database']]],
  ['db_5ffunctions',['DB_FUNCTIONS',['../namespace_sql_util.html#ae624d72f6c5e974cff42b38bfa0d3ef9',1,'SqlUtil']]],
  ['db_5fmviews',['DB_MVIEWS',['../namespace_sql_util.html#a5a138440c28ea7a20cc301a7a546397f',1,'SqlUtil']]],
  ['db_5fpackages',['DB_PACKAGES',['../namespace_sql_util.html#a1ce94dd1f978cb1b22c75c7e3f6a418e',1,'SqlUtil']]],
  ['db_5fprocedures',['DB_PROCEDURES',['../namespace_sql_util.html#a94f9172d04a891ce648a2b462ba6cacd',1,'SqlUtil']]],
  ['db_5fsequences',['DB_SEQUENCES',['../namespace_sql_util.html#af691e709f12db51da8ed4938b730047d',1,'SqlUtil']]],
  ['db_5fsynonyms',['DB_SYNONYMS',['../namespace_sql_util.html#a1ab57e4a5d09f38490ed181003a06a1d',1,'SqlUtil']]],
  ['db_5ftables',['DB_TABLES',['../namespace_sql_util.html#aaea27e7ce6be034c14f74985aa0d1ae0',1,'SqlUtil']]],
  ['db_5ftypes',['DB_TYPES',['../namespace_sql_util.html#af70f6295063645aa3aa9731e33c212cc',1,'SqlUtil']]],
  ['db_5fviews',['DB_VIEWS',['../namespace_sql_util.html#ac01e40dff665219610a27eaed220fa1b',1,'SqlUtil']]],
  ['dbi_5fcap_5fautoreconnect',['DBI_CAP_AUTORECONNECT',['../../../../lang/html/group__dbi__capabilities.html#gae77508d8a9b7f53e3f0a35f76cf59511',1,'Qore::SQL::DBI_CAP_AUTORECONNECT()'],['../../../../lang/html/group__dbi__capabilities.html#gae77508d8a9b7f53e3f0a35f76cf59511',1,'DBI_CAP_AUTORECONNECT()(Global Namespace)']]],
  ['dbi_5fcap_5fbind_5fby_5fplaceholder',['DBI_CAP_BIND_BY_PLACEHOLDER',['../../../../lang/html/group__dbi__capabilities.html#gac6adedead4bf1317f03b575dc1276351',1,'Qore::SQL::DBI_CAP_BIND_BY_PLACEHOLDER()'],['../../../../lang/html/group__dbi__capabilities.html#gac6adedead4bf1317f03b575dc1276351',1,'DBI_CAP_BIND_BY_PLACEHOLDER()(Global Namespace)']]],
  ['dbi_5fcap_5fbind_5fby_5fvalue',['DBI_CAP_BIND_BY_VALUE',['../../../../lang/html/group__dbi__capabilities.html#ga369027092e18434a428c0ba401986964',1,'Qore::SQL::DBI_CAP_BIND_BY_VALUE()'],['../../../../lang/html/group__dbi__capabilities.html#ga369027092e18434a428c0ba401986964',1,'DBI_CAP_BIND_BY_VALUE()(Global Namespace)']]],
  ['dbi_5fcap_5fcharset_5fsupport',['DBI_CAP_CHARSET_SUPPORT',['../../../../lang/html/group__dbi__capabilities.html#ga382bb241f164431cf2e5c0e161b1bdd2',1,'Qore::SQL::DBI_CAP_CHARSET_SUPPORT()'],['../../../../lang/html/group__dbi__capabilities.html#ga382bb241f164431cf2e5c0e161b1bdd2',1,'DBI_CAP_CHARSET_SUPPORT()(Global Namespace)']]],
  ['dbi_5fcap_5fevents',['DBI_CAP_EVENTS',['../../../../lang/html/group__dbi__capabilities.html#gae187e09b0775647d1b1afd2d3b43570f',1,'Qore::SQL::DBI_CAP_EVENTS()'],['../../../../lang/html/group__dbi__capabilities.html#gae187e09b0775647d1b1afd2d3b43570f',1,'DBI_CAP_EVENTS()(Global Namespace)']]],
  ['dbi_5fcap_5fhas_5farray_5fbind',['DBI_CAP_HAS_ARRAY_BIND',['../../../../lang/html/group__dbi__capabilities.html#ga87128ed8eccc517cb36ceb5f27ceaa53',1,'Qore::SQL::DBI_CAP_HAS_ARRAY_BIND()'],['../../../../lang/html/group__dbi__capabilities.html#ga87128ed8eccc517cb36ceb5f27ceaa53',1,'DBI_CAP_HAS_ARRAY_BIND()(Global Namespace)']]],
  ['dbi_5fcap_5fhas_5fdescribe',['DBI_CAP_HAS_DESCRIBE',['../../../../lang/html/group__dbi__capabilities.html#ga775d0748c664e8ced5a2ef953496aa8c',1,'Qore::SQL::DBI_CAP_HAS_DESCRIBE()'],['../../../../lang/html/group__dbi__capabilities.html#ga775d0748c664e8ced5a2ef953496aa8c',1,'DBI_CAP_HAS_DESCRIBE()(Global Namespace)']]],
  ['dbi_5fcap_5fhas_5fexecraw',['DBI_CAP_HAS_EXECRAW',['../../../../lang/html/group__dbi__capabilities.html#gad3033ee84e18d57a95da98e01bdae383',1,'Qore::SQL::DBI_CAP_HAS_EXECRAW()'],['../../../../lang/html/group__dbi__capabilities.html#gad3033ee84e18d57a95da98e01bdae383',1,'DBI_CAP_HAS_EXECRAW()(Global Namespace)']]],
  ['dbi_5fcap_5fhas_5fnumber_5fsupport',['DBI_CAP_HAS_NUMBER_SUPPORT',['../../../../lang/html/group__dbi__capabilities.html#ga8394d1495944bf61d666de40489a038a',1,'Qore::SQL::DBI_CAP_HAS_NUMBER_SUPPORT()'],['../../../../lang/html/group__dbi__capabilities.html#ga8394d1495944bf61d666de40489a038a',1,'DBI_CAP_HAS_NUMBER_SUPPORT()(Global Namespace)']]],
  ['dbi_5fcap_5fhas_5foption_5fsupport',['DBI_CAP_HAS_OPTION_SUPPORT',['../../../../lang/html/group__dbi__capabilities.html#ga428f8f4909b2737d03593d8808fe2227',1,'Qore::SQL::DBI_CAP_HAS_OPTION_SUPPORT()'],['../../../../lang/html/group__dbi__capabilities.html#ga428f8f4909b2737d03593d8808fe2227',1,'DBI_CAP_HAS_OPTION_SUPPORT()(Global Namespace)']]],
  ['dbi_5fcap_5fhas_5fselect_5frow',['DBI_CAP_HAS_SELECT_ROW',['../../../../lang/html/group__dbi__capabilities.html#ga8a1c46d41ccafebf758dfe3d1116657c',1,'Qore::SQL::DBI_CAP_HAS_SELECT_ROW()'],['../../../../lang/html/group__dbi__capabilities.html#ga8a1c46d41ccafebf758dfe3d1116657c',1,'DBI_CAP_HAS_SELECT_ROW()(Global Namespace)']]],
  ['dbi_5fcap_5fhas_5fstatement',['DBI_CAP_HAS_STATEMENT',['../../../../lang/html/group__dbi__capabilities.html#ga527e40359b876f12a4cb59fec305969d',1,'Qore::SQL::DBI_CAP_HAS_STATEMENT()'],['../../../../lang/html/group__dbi__capabilities.html#ga527e40359b876f12a4cb59fec305969d',1,'DBI_CAP_HAS_STATEMENT()(Global Namespace)']]],
  ['dbi_5fcap_5flob_5fsupport',['DBI_CAP_LOB_SUPPORT',['../../../../lang/html/group__dbi__capabilities.html#ga3a641cb4afbeb873fd9fe97f020f09eb',1,'Qore::SQL::DBI_CAP_LOB_SUPPORT()'],['../../../../lang/html/group__dbi__capabilities.html#ga3a641cb4afbeb873fd9fe97f020f09eb',1,'DBI_CAP_LOB_SUPPORT()(Global Namespace)']]],
  ['dbi_5fcap_5fserver_5ftime_5fzone',['DBI_CAP_SERVER_TIME_ZONE',['../../../../lang/html/group__dbi__capabilities.html#ga9edf0826e734f77115fd8f1001cf4a9e',1,'Qore::SQL::DBI_CAP_SERVER_TIME_ZONE()'],['../../../../lang/html/group__dbi__capabilities.html#ga9edf0826e734f77115fd8f1001cf4a9e',1,'DBI_CAP_SERVER_TIME_ZONE()(Global Namespace)']]],
  ['dbi_5fcap_5fstored_5fprocedures',['DBI_CAP_STORED_PROCEDURES',['../../../../lang/html/group__dbi__capabilities.html#gac5e26138ae8e0957e7dba50d8a96cb6c',1,'Qore::SQL::DBI_CAP_STORED_PROCEDURES()'],['../../../../lang/html/group__dbi__capabilities.html#gac5e26138ae8e0957e7dba50d8a96cb6c',1,'DBI_CAP_STORED_PROCEDURES()(Global Namespace)']]],
  ['dbi_5fcap_5ftime_5fzone_5fsupport',['DBI_CAP_TIME_ZONE_SUPPORT',['../../../../lang/html/group__dbi__capabilities.html#gab97795225e7b52a4a063c1770c4fec7c',1,'Qore::SQL::DBI_CAP_TIME_ZONE_SUPPORT()'],['../../../../lang/html/group__dbi__capabilities.html#gab97795225e7b52a4a063c1770c4fec7c',1,'DBI_CAP_TIME_ZONE_SUPPORT()(Global Namespace)']]],
  ['dbi_5fcap_5ftransaction_5fmanagement',['DBI_CAP_TRANSACTION_MANAGEMENT',['../../../../lang/html/group__dbi__capabilities.html#ga62b0bd7a4e0611fbe8848002aa6711c8',1,'Qore::SQL::DBI_CAP_TRANSACTION_MANAGEMENT()'],['../../../../lang/html/group__dbi__capabilities.html#ga62b0bd7a4e0611fbe8848002aa6711c8',1,'DBI_CAP_TRANSACTION_MANAGEMENT()(Global Namespace)']]],
  ['decimal',['DECIMAL',['../../../../lang/html/group__sql__constants.html#ga85bba3f8e978509f66f08011b264e9b0',1,'Qore::SQL::DECIMAL()'],['../../../../lang/html/group__sql__constants.html#ga85bba3f8e978509f66f08011b264e9b0',1,'DECIMAL()(Global Namespace)']]],
  ['def_5fval',['def_val',['../class_sql_util_1_1_abstract_column.html#a519e6ac1e7288647898baf62720219be',1,'SqlUtil::AbstractColumn']]],
  ['defaultcopmap',['DefaultCopMap',['../group__sql__cops.html#gae497d7c4b1316f78ea93522f8b7cd554',1,'SqlUtil']]],
  ['defaultiopmap',['DefaultIopMap',['../group__sql__iops.html#ga82d74e87e1f9365eeb902dce0a481132',1,'SqlUtil']]],
  ['defaultiv',['DefaultIV',['../../../../lang/html/group__cryptographic__constants.html#ga3e258a2c4d9e99eb43a97e7bf1dbe870',1,'Qore::DefaultIV()'],['../../../../lang/html/group__cryptographic__constants.html#ga3e258a2c4d9e99eb43a97e7bf1dbe870',1,'DefaultIV()(Global Namespace)']]],
  ['defaultopmap',['DefaultOpMap',['../group__sql__ops.html#ga48d22f47fdbfb3cc9053235a709f2a17',1,'SqlUtil']]],
  ['defaultuopmap',['DefaultUopMap',['../group__sql__uops.html#ga1f1c6a2c131d48856844f8de25976bc5',1,'SqlUtil']]],
  ['dirsep',['DirSep',['../../../../lang/html/group__system__and__build__constants.html#ga6cebae5097d4414ca8c6da4be8cf9922',1,'Qore::DirSep()'],['../../../../lang/html/group__system__and__build__constants.html#ga6cebae5097d4414ca8c6da4be8cf9922',1,'DirSep()(Global Namespace)']]],
  ['dropschemaoptions',['DropSchemaOptions',['../class_sql_util_1_1_abstract_database.html#a1316a5c73ddff6d6f38cf6460c6df798',1,'SqlUtil::AbstractDatabase']]],
  ['ds',['ds',['../class_sql_util_1_1_abstract_sql_util_base.html#a9702e036a29d0001b493ba8fe087f612',1,'SqlUtil::AbstractSqlUtilBase']]],
  ['dsdb2',['DSDB2',['../../../../lang/html/group__database__driver__constants.html#ga0baaf1dccf027f143466257478c8b647',1,'Qore::SQL::DSDB2()'],['../../../../lang/html/group__database__driver__constants.html#ga0baaf1dccf027f143466257478c8b647',1,'DSDB2()(Global Namespace)']]],
  ['dsdesc',['dsdesc',['../class_sql_util_1_1_abstract_sql_util_base.html#a99e661a4e2125368244a09c93c8aab8d',1,'SqlUtil::AbstractSqlUtilBase']]],
  ['dsfreetds',['DSFreeTDS',['../../../../lang/html/group__database__driver__constants.html#ga3e14e0949befa85b7c2993dd7a369811',1,'Qore::SQL::DSFreeTDS()'],['../../../../lang/html/group__database__driver__constants.html#ga3e14e0949befa85b7c2993dd7a369811',1,'DSFreeTDS()(Global Namespace)']]],
  ['dsmssql',['DSMSSQL',['../../../../lang/html/group__database__driver__constants.html#ga6cec46106d85f35a513ebb3d7b751cef',1,'Qore::SQL::DSMSSQL()'],['../../../../lang/html/group__database__driver__constants.html#ga6cec46106d85f35a513ebb3d7b751cef',1,'DSMSSQL()(Global Namespace)']]],
  ['dsmysql',['DSMySQL',['../../../../lang/html/group__database__driver__constants.html#ga09de83cb35f39d717e612dffc0d55cf6',1,'Qore::SQL::DSMySQL()'],['../../../../lang/html/group__database__driver__constants.html#ga09de83cb35f39d717e612dffc0d55cf6',1,'DSMySQL()(Global Namespace)']]],
  ['dsoracle',['DSOracle',['../../../../lang/html/group__database__driver__constants.html#gada3f880c40b777b843b944d585404e70',1,'Qore::SQL::DSOracle()'],['../../../../lang/html/group__database__driver__constants.html#gada3f880c40b777b843b944d585404e70',1,'DSOracle()(Global Namespace)']]],
  ['dspgsql',['DSPGSQL',['../../../../lang/html/group__database__driver__constants.html#gac3ce6e6daf3c2bedbc927905e744b45b',1,'Qore::SQL::DSPGSQL()'],['../../../../lang/html/group__database__driver__constants.html#gac3ce6e6daf3c2bedbc927905e744b45b',1,'DSPGSQL()(Global Namespace)']]],
  ['dssqlite3',['DSSQLite3',['../../../../lang/html/group__database__driver__constants.html#ga116c8e3a222a4f13965519d9241665c3',1,'Qore::SQL::DSSQLite3()'],['../../../../lang/html/group__database__driver__constants.html#ga116c8e3a222a4f13965519d9241665c3',1,'DSSQLite3()(Global Namespace)']]],
  ['dssybase',['DSSybase',['../../../../lang/html/group__database__driver__constants.html#ga39a5356b7cee1ef4b8a47e02dfe65f05',1,'Qore::SQL::DSSybase()'],['../../../../lang/html/group__database__driver__constants.html#ga39a5356b7cee1ef4b8a47e02dfe65f05',1,'DSSybase()(Global Namespace)']]]
];
